/*
 Tecnisa - Tecnologia em Informtica

 Nome: GERA_TRAB_PREV_RISOTOLANDIA - 1071_FINSTP_GERA_TRAB_PREV_RISOTOLANDIA.SQL

 Descrio:
 Grava os dados referentes ao relatrio de Fluxo de Caixa - Duplicatas (Formulrio)

 STP - Especfica do relatrio Fluxo de Caixa - Duplicatas (Formulrio)
  Obs.: Este relatrio  especfico do cliente Risotolandia

 Criao:
 09/10/2002 - Jenilson Ferreira

 EXEC GERA_TRAB_PREV_RISOTOLANDIA('9999', '0000000001', '02/11/2002', '09/11/2002', 'T')
 SET SERVEROUTPUT ON

 - Grupo 99: Ser utilizado para guardar a movimentao dos dias anteriores
*/

CREATE OR REPLACE PROCEDURE GERA_TRAB_PREV_RISOTOLANDIA
   (P_CDFILIAL    IN TRAB_PREV.CDFILIPREV%TYPE,
    P_NRPREVISAO  IN TRAB_PREV.NRPREVISAO%TYPE,
    P_DTPERIINIC  IN DATE,
    P_DTPERIFINA  IN DATE,
    P_CDEMPRESA   IN VARCHAR2)

AS
   V_NRPAGINA    NUMBER;
   V_NRREGIENCA  NUMBER;
   V_NRCOLUNA    NUMBER;
   V_TOTALDIA    NUMBER;
   V_CTSALDO     NUMBER;
   V_CTCONTA     NUMBER;
   V_TOTMOVIANT  NUMBER;
   V_VRDIA01     NUMBER;
   V_CTCONTAREC  NUMBER;
   V_IDATRASO    VARCHAR2(1);
   V_ISEMPTY     VARCHAR2(1);
   V_DATADIA     DATE;

   CURSOR C_PERIODO IS
      SELECT DTDATA
      FROM DATA
      WHERE
         DTDATA BETWEEN (P_DTPERIINIC - 1) AND P_DTPERIFINA;

   CURSOR C_BANCOS IS
      SELECT DISTINCT
         CC.CDEMPRESA, BC.CDBANCO, BC.NMBANCO
      FROM CONTCORR CC, BANCO BC
      WHERE (CC.CDBANCO  = BC.CDBANCO) AND
            (P_CDEMPRESA = 'T' OR INSTR(P_CDEMPRESA, CDEMPRESA) <> 0)
      ORDER BY CC.CDEMPRESA, BC.CDBANCO;

   CURSOR C_EMPRESA IS
      SELECT CDEMPRESA, NMEMPRESA
      FROM EMPRESA
      WHERE
         (P_CDEMPRESA = 'T' OR INSTR(P_CDEMPRESA, CDEMPRESA) <> 0)
      ORDER BY CDEMPRESA;

   CURSOR C_CLASSFINANC IS
      SELECT CDCLASSFINA, DSCLASSFINA
      FROM CLASSFINANC
      ORDER BY CDCLASSFINA;

BEGIN
   /* ----- GRAVA O SALDO DOS BANCOS ----- */
   V_NRREGIENCA := 1;
   FOR C_BC IN C_BANCOS LOOP
      V_NRCOLUNA   := 1;
      V_NRPAGINA   := 1;
      FOR C_DATA IN C_PERIODO LOOP
         SELECT COUNT(*) INTO V_CTSALDO
         FROM CONTCORR CC, SDOCCORR SC
         WHERE
            (CC.CDREDUCONT = SC.CDREDUCONT)    AND
            (CC.CDEMPRESA  = C_BC.CDEMPRESA)   AND
            (CC.CDBANCO    = C_BC.CDBANCO)     AND
            (SC.DTSDOCCORR IN (SELECT MAX(DTSDOCCORR)
                               FROM SDOCCORR
                               WHERE
                                  CDREDUCONT = SC.CDREDUCONT AND
                                  DTSDOCCORR <= C_DATA.DTDATA));

         V_TOTALDIA := 0;
         IF V_CTSALDO > 0 THEN
            SELECT SUM(VRSDOCCORR) INTO V_TOTALDIA
            FROM CONTCORR CC, SDOCCORR SC
            WHERE
               (CC.CDREDUCONT = SC.CDREDUCONT)    AND
               (CC.CDEMPRESA  = C_BC.CDEMPRESA)   AND
               (CC.CDBANCO    = C_BC.CDBANCO)     AND
               (SC.DTSDOCCORR IN (SELECT MAX(DTSDOCCORR)
                                  FROM SDOCCORR
                                  WHERE
                                     CDREDUCONT = SC.CDREDUCONT AND
                                     DTSDOCCORR <= C_DATA.DTDATA));
         END IF;

         IF V_NRCOLUNA > 1 THEN
            ALTERA_TRAB_PREV(P_CDFILIAL, P_NRPREVISAO, LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
                             V_NRCOLUNA, C_DATA.DTDATA, V_TOTALDIA);
         ELSE
            INSERT INTO TRAB_PREV(
               CDFILIPREV,   NRPREVISAO, NRREGIPREV,
               NRPAGIPREV,   CDGRUPPREV, CDEMPRPREV,
               CDITEMPREV,   DSITEMPREV, VRATRASOPREV,
               DTDIA01PREV,  VRDIA01PREV,
               DTINIPERPREV, DTFINPERPREV)
            VALUES(
               P_CDFILIAL,    P_NRPREVISAO, LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
               V_NRPAGINA,    '01',         C_BC.CDEMPRESA,
               C_BC.CDBANCO,  C_BC.NMBANCO, 0,
               C_DATA.DTDATA, V_TOTALDIA,
               P_DTPERIINIC,  P_DTPERIFINA);
         END IF;

         /* CONTROLA A COLUNA E A PGINA DO RELATRIO*/
         V_NRCOLUNA   := V_NRCOLUNA + 1;
         IF V_NRCOLUNA > 6 THEN
            V_NRPAGINA   := V_NRPAGINA + 1;
            V_NRCOLUNA   := 1;
            V_NRREGIENCA := V_NRREGIENCA + 1;
         END IF;
      END LOOP;
      V_NRREGIENCA := V_NRREGIENCA + 1;
   END LOOP;

   /* ----- GRAVA O VALOR DAS CONTAS A RECEBER ----- */
   FOR C_EMP IN C_EMPRESA LOOP
         V_NRPAGINA   := 1;

         /* ----------------------------------------------------------------- */
         /* GRAVA OS VALORES DAS CONTAS A RECEBER EM ATRASO */
         V_TOTALDIA := 0;
         SELECT SUM(VRFINALBREC) INTO V_TOTALDIA
         FROM
            (SELECT DISTINCT BR.CDFILIAL, BR.NRLANBOLREC, BR.VRFINALBREC
             FROM
                NOTAFISCAL NF, BOLETRECEBER BR, CONTARECEBER CR
             WHERE
                CR.CDEMPRESA   = C_EMP.CDEMPRESA      AND
                CR.DTATUAVENREC <= (P_DTPERIINIC - 2) AND
                CR.IDSTATREC IN ('A', 'E')            AND
                NOT CR.NRLANCTODUP IS NULL            AND
                NF.CDFILIAL   = CR.CDFILIAL           AND
                NF.NRLANCTONF = CR.NRLANCTONF         AND
                NF.IDSTATUS  IN ('A', 'E')            AND
                BR.CDFILIAL    = CR.CDFILIBOLREC      AND
                BR.NRLANBOLREC = CR.NRLANBOLREC
             UNION ALL
             SELECT DISTINCT BR.CDFILIAL, BR.NRLANBOLREC, BR.VRFINALBREC
             FROM NOTAFISCAL NF, BOLETRECEBER BR, CONTARECEBER CR
             WHERE
                CR.CDEMPRESA    = C_EMP.CDEMPRESA     AND
                CR.DTATUAVENREC <= (P_DTPERIINIC - 2) AND
                CR.IDSTATREC IN ('A', 'E')            AND
                NF.CDFILIAL    = CR.CDFILIAL          AND
                NF.NRLANCTONF  = CR.NRLANCTONF        AND
                NF.IDSISTEMA   = 'REC'                AND
                NF.IDSTATUS  IN ('A', 'E')            AND
                BR.CDFILIAL    = CR.CDFILIBOLREC      AND
                BR.NRLANBOLREC = CR.NRLANBOLREC);

         V_IDATRASO := 'N';
         IF V_TOTALDIA > 0 THEN
            INSERT INTO TRAB_PREV(
               CDFILIPREV,   NRPREVISAO, NRREGIPREV,
               NRPAGIPREV,   CDGRUPPREV, CDEMPRPREV,
               CDITEMPREV,   DSITEMPREV, VRATRASOPREV,
               DTINIPERPREV, DTFINPERPREV)
            VALUES(
               P_CDFILIAL,          P_NRPREVISAO,        LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
               V_NRPAGINA,          '02',                C_EMP.CDEMPRESA,
               '', '', V_TOTALDIA,
               P_DTPERIINIC,        P_DTPERIFINA);

               V_IDATRASO := 'S';
         END IF;

         /* ----------------------------------------------------------------- */
         /* GRAVA OS VALORES DAS CONTAS A RECEBER */
         SELECT COUNT(*) INTO V_CTCONTA
         FROM CONTARECEBER
         WHERE
            CDEMPRESA    = C_EMP.CDEMPRESA     AND
            DTATUAVENREC BETWEEN (P_DTPERIINIC - 1) AND P_DTPERIFINA;

         IF (V_IDATRASO = 'S') OR (V_CTCONTA > 0) THEN
            V_NRCOLUNA := 1;
            FOR C_DATA IN C_PERIODO LOOP

               V_TOTALDIA := 0;
               FOR C_CNTREC IN (
                SELECT SUM(VRFINALBREC) VRDUPLICATA
                  FROM
                    (SELECT DISTINCT BR.CDFILIAL, BR.NRLANBOLREC, BR.VRFINALBREC
                       FROM
                        NOTAFISCAL NF, BOLETRECEBER BR, CONTARECEBER CR
                     WHERE
                        CR.CDEMPRESA    = C_EMP.CDEMPRESA   AND
                        DECODE(BR.IDSTATBREC,'E',(CR.DTATUAVENREC+1),CR.DTATUAVENREC) = C_DATA.DTDATA     AND
                        CR.IDSTATREC IN ('A', 'E')          AND
                        NOT CR.NRLANCTODUP IS NULL          AND
                        NF.CDFILIAL     = CR.CDFILIAL       AND
                        NF.NRLANCTONF   = CR.NRLANCTONF     AND
                        NF.IDSTATUS  IN ('A', 'E')          AND
                        BR.CDFILIAL     = CR.CDFILIBOLREC   AND
                        BR.NRLANBOLREC  = CR.NRLANBOLREC
                     UNION ALL
                     SELECT DISTINCT BR.CDFILIAL, BR.NRLANBOLREC, BR.VRFINALBREC
                      FROM NOTAFISCAL NF, BOLETRECEBER BR, CONTARECEBER CR
                     WHERE
                        CR.CDEMPRESA    = C_EMP.CDEMPRESA   AND
                        DECODE(BR.IDSTATBREC,'E',(CR.DTATUAVENREC+1),CR.DTATUAVENREC) = C_DATA.DTDATA     AND
                        CR.IDSTATREC IN ('A', 'E')          AND
                        NF.CDFILIAL    = CR.CDFILIAL        AND
                        NF.NRLANCTONF  = CR.NRLANCTONF      AND
                        NF.IDSISTEMA   = 'REC'              AND
                        NF.IDSTATUS  IN ('A', 'E')          AND
                        BR.CDFILIAL     = CR.CDFILIBOLREC   AND
                        BR.NRLANBOLREC  = CR.NRLANBOLREC)) LOOP

                  IF C_CNTREC.VRDUPLICATA IS NULL THEN
                     V_TOTALDIA := V_TOTALDIA + 0;
                  ELSE
                     V_TOTALDIA := V_TOTALDIA + C_CNTREC.VRDUPLICATA;
                  END IF;

               END LOOP;

               IF (V_NRCOLUNA > 1) OR (V_IDATRASO = 'S') THEN
/*                  DBMS_OUTPUT.PUT_LINE('AREC: '||LPAD(TO_CHAR(V_NRREGIENCA), 10, '0')||'-'||V_NRPAGINA||'-'||C_EMP.CDEMPRESA||'-'||V_NRCOLUNA||'-'||C_DATA.DTDATA||'-'||V_TOTALDIA); */
                  ALTERA_TRAB_PREV(P_CDFILIAL, P_NRPREVISAO,  LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
                                   V_NRCOLUNA, C_DATA.DTDATA, V_TOTALDIA);
               ELSE
/*                  DBMS_OUTPUT.PUT_LINE('IREC: '||LPAD(TO_CHAR(V_NRREGIENCA), 10, '0')||'-'||V_NRPAGINA||'-'||C_EMP.CDEMPRESA||'-'||V_NRCOLUNA||'-'||C_DATA.DTDATA||'-'||V_TOTALDIA); */
                  INSERT INTO TRAB_PREV(
                     CDFILIPREV,   NRPREVISAO, NRREGIPREV,
                     NRPAGIPREV,   CDGRUPPREV, CDEMPRPREV,
                     CDITEMPREV,   DSITEMPREV,
                     DTDIA01PREV,  VRDIA01PREV,
                     DTINIPERPREV, DTFINPERPREV)
                  VALUES(
                     P_CDFILIAL,          P_NRPREVISAO, LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
                     V_NRPAGINA,          '02',         C_EMP.CDEMPRESA,
                     '', '',
                     C_DATA.DTDATA,       V_TOTALDIA,
                     P_DTPERIINIC,        P_DTPERIFINA);
               END IF;

               /* CONTROLA A COLUNA E A PGINA DO RELATRIO */
               V_NRCOLUNA   := V_NRCOLUNA + 1;
               IF V_NRCOLUNA > 6 THEN
                  V_NRPAGINA   := V_NRPAGINA + 1;
                  V_NRCOLUNA   := 1;
                  V_NRREGIENCA := V_NRREGIENCA + 1;
                  V_IDATRASO   := 'N';
               END IF;
            END LOOP;
            V_NRREGIENCA := V_NRREGIENCA + 1;
         END IF;
      /*END LOOP;*/
   END LOOP;

   /* ----- GRAVA O VALOR DAS CONTAS A PAGAR ----- */
   FOR C_EMP IN C_EMPRESA LOOP
         V_NRPAGINA   := 1;
         /* GRAVA OS VALORES DAS CONTAS A PAGAR EM ATRASO */
         V_TOTALDIA := 0;
         SELECT SUM(VRATUAPAG) INTO V_TOTALDIA
         FROM
          (SELECT SUM(CP.VRATUAPAG) VRATUAPAG
           FROM
              NOTAFISCAL NF,
              CONTAPAGAR CP
           WHERE
              CP.CDEMPRESA    = C_EMP.CDEMPRESA      AND
              CP.DTATUAVENPAG <= (P_DTPERIINIC - 2)  AND
              CP.IDSTATPAG    = 'A'                  AND
              NF.CDFILIAL     = CP.CDFILIAL          AND
              NF.NRLANCTONF   = CP.NRLANCTONF        AND
              NF.IDSTATUS     = 'A'
           UNION
           SELECT SUM(MJ.VRFXAJBOLPAG) VRATUAPAG
           FROM TIPOAJPAGAR TA, MOVFXAJBOLP MJ
           WHERE
              MJ.CDEMPRESA   = C_EMP.CDEMPRESA      AND
              MJ.DTMOVFLUXO  <= (P_DTPERIINIC - 2)  AND
              MJ.IDMOVFLUXO  = 'E'                  AND
              MJ.CDAJUCTPAG  = TA.CDAJUCTPAG        AND
              TA.IDAJUCTPAG  = 'A'
           UNION
           SELECT SUM(MJ.VRFXAJBOLPAG * -1) VRATUAPAG
           FROM TIPOAJPAGAR TA, MOVFXAJBOLP MJ
           WHERE
              MJ.CDEMPRESA   = C_EMP.CDEMPRESA      AND
              MJ.DTMOVFLUXO  <= (P_DTPERIINIC - 2)  AND
              MJ.IDMOVFLUXO  = 'E'                  AND
              MJ.CDAJUCTPAG  = TA.CDAJUCTPAG        AND
              TA.IDAJUCTPAG  = 'D');

         V_IDATRASO := 'N';
         IF V_TOTALDIA > 0 THEN
            INSERT INTO TRAB_PREV(
               CDFILIPREV,   NRPREVISAO, NRREGIPREV,
               NRPAGIPREV,   CDGRUPPREV, CDEMPRPREV,
               CDITEMPREV,   DSITEMPREV, VRATRASOPREV,
               DTINIPERPREV, DTFINPERPREV)
            VALUES(
               P_CDFILIAL,          P_NRPREVISAO,        LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
               V_NRPAGINA,          '03',                C_EMP.CDEMPRESA,
               '', '', -V_TOTALDIA,
               P_DTPERIINIC,        P_DTPERIFINA);

               V_IDATRASO := 'S';
         END IF;

         SELECT COUNT(*) INTO V_CTCONTA
         FROM CONTAPAGAR
         WHERE
            CDEMPRESA    = C_EMP.CDEMPRESA     AND
            DTATUAVENPAG BETWEEN (P_DTPERIINIC - 1) AND P_DTPERIFINA;

         IF (V_IDATRASO = 'S') OR (V_CTCONTA > 0) THEN
            /* GRAVA OS VALORES DAS CONTAS A PAGAR */
            V_NRCOLUNA := 1;
            FOR C_DATA IN C_PERIODO LOOP

               V_TOTALDIA := 0;
               FOR C_CNTREC IN (
                  SELECT SUM(CP.VRATUAPAG) VRATUAPAG
                  FROM
                     NOTAFISCAL NF,
                     CONTAPAGAR CP
                  WHERE
                     CP.CDEMPRESA    = C_EMP.CDEMPRESA      AND
                     CP.DTATUAVENPAG = C_DATA.DTDATA        AND
                     CP.IDSTATPAG    = 'A'                  AND
                     NF.CDFILIAL     = CP.CDFILIAL          AND
                     NF.NRLANCTONF   = CP.NRLANCTONF        AND
                     NF.IDSTATUS     = 'A'
                  UNION
                  SELECT SUM(MJ.VRFXAJBOLPAG) VRATUAPAG
                  FROM TIPOAJPAGAR TA, MOVFXAJBOLP MJ
                  WHERE
                     MJ.CDEMPRESA   = C_EMP.CDEMPRESA      AND
                     MJ.DTMOVFLUXO  = C_DATA.DTDATA        AND
                     MJ.IDMOVFLUXO  = 'E'                  AND
                     MJ.CDAJUCTPAG  = TA.CDAJUCTPAG        AND
                     TA.IDAJUCTPAG  = 'A'
                  UNION
                  SELECT SUM(MJ.VRFXAJBOLPAG * -1) VRATUAPAG
                  FROM TIPOAJPAGAR TA, MOVFXAJBOLP MJ
                  WHERE
                     MJ.CDEMPRESA   = C_EMP.CDEMPRESA      AND
                     MJ.DTMOVFLUXO  = C_DATA.DTDATA        AND
                     MJ.IDMOVFLUXO  = 'E'                  AND
                     MJ.CDAJUCTPAG  = TA.CDAJUCTPAG        AND
                     TA.IDAJUCTPAG  = 'D') LOOP
                  IF C_CNTREC.VRATUAPAG IS NULL THEN
                     V_TOTALDIA := V_TOTALDIA + 0;
                  ELSE
                     V_TOTALDIA := V_TOTALDIA - C_CNTREC.VRATUAPAG;
                  END IF;
               END LOOP;

               IF (V_NRCOLUNA > 1) OR (V_IDATRASO = 'S') THEN
                  ALTERA_TRAB_PREV(P_CDFILIAL, P_NRPREVISAO,  LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
                                   V_NRCOLUNA, C_DATA.DTDATA, V_TOTALDIA);
               ELSE
                  INSERT INTO TRAB_PREV(
                     CDFILIPREV,   NRPREVISAO, NRREGIPREV,
                     NRPAGIPREV,   CDGRUPPREV, CDEMPRPREV,
                     CDITEMPREV,   DSITEMPREV,
                     DTDIA01PREV,  VRDIA01PREV,
                     DTINIPERPREV, DTFINPERPREV)
                  VALUES(
                     P_CDFILIAL,          P_NRPREVISAO, LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
                     V_NRPAGINA,          '03',         C_EMP.CDEMPRESA,
                     '', '',
                     C_DATA.DTDATA,       V_TOTALDIA,
                     P_DTPERIINIC,        P_DTPERIFINA);
               END IF;

               /* CONTROLA A COLUNA E A PGINA DO RELATRIO */
               V_NRCOLUNA   := V_NRCOLUNA + 1;
               IF V_NRCOLUNA > 6 THEN
                  V_NRPAGINA   := V_NRPAGINA + 1;
                  V_NRCOLUNA   := 1;
                  V_NRREGIENCA := V_NRREGIENCA + 1;
                  V_IDATRASO   := 'N';
               END IF;
            END LOOP;
            V_NRREGIENCA := V_NRREGIENCA + 1;
         END IF;
      /*END LOOP;*/
   END LOOP;

   FOR C_EMP IN C_EMPRESA LOOP
      V_NRPAGINA   := 1;
      V_NRCOLUNA   := 1;
      FOR C_DATA IN C_PERIODO LOOP

         V_TOTALDIA := 0;
         FOR C_PREVENT IN
           (SELECT CDCLIENTE, SUM(VRPREVENTR) VRPREVENTR
            FROM PREVENTRADA
            WHERE
               DTPREVENTR = C_DATA.DTDATA AND
               CDEMPRESA  = C_EMP.CDEMPRESA
            GROUP BY CDCLIENTE) LOOP

            SELECT COUNT(CDFILIAL)
            INTO V_CTCONTA
            FROM
               (SELECT DISTINCT NF.CDFILIAL
                FROM
                   NOTAFISCAL NF, CONTARECEBER CR, DUPLICATA DP
                WHERE
                   CR.CDEMPRESA   = C_EMP.CDEMPRESA     AND
                   DP.DTVENCDUP   = C_DATA.DTDATA       AND
                   NF.CDCLIENTE   = C_PREVENT.CDCLIENTE AND
                   CR.CDFILIALDUP = DP.CDFILIAL         AND
                   CR.NRLANCTODUP = DP.NRLANCTODUP      AND
                   NF.CDFILIAL    = CR.CDFILIAL         AND
                   NF.NRLANCTONF  = CR.NRLANCTONF       AND
                   NF.IDSTATUS  IN ('A', 'E')
                UNION ALL
                SELECT DISTINCT NF.CDFILIAL
                FROM NOTAFISCAL NF, CONTARECEBER CR
                WHERE
                   CR.CDEMPRESA    = C_EMP.CDEMPRESA     AND
                   CR.DTORIGVENREC = C_DATA.DTDATA       AND
                   NF.CDFILIAL     = CR.CDFILIAL         AND
                   NF.NRLANCTONF   = CR.NRLANCTONF       AND
                   NF.IDSISTEMA    = 'REC'               AND
                   NF.IDSTATUS  IN ('A', 'E')            AND
                   CR.NRLANCTODUP IS NULL                AND
                   NF.CDCLIENTE    = C_PREVENT.CDCLIENTE
               );

            IF V_CTCONTA = 0 THEN
               V_TOTALDIA := V_TOTALDIA + C_PREVENT.VRPREVENTR;
            END IF;
         END LOOP;

         IF (V_NRCOLUNA > 1) THEN
            ALTERA_TRAB_PREV(P_CDFILIAL, P_NRPREVISAO,  LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
                             V_NRCOLUNA, C_DATA.DTDATA, V_TOTALDIA);
         ELSE
            INSERT INTO TRAB_PREV(
               CDFILIPREV,   NRPREVISAO, NRREGIPREV,
               NRPAGIPREV,   CDGRUPPREV, CDEMPRPREV,
               CDITEMPREV,   DSITEMPREV,
               DTDIA01PREV,  VRDIA01PREV,
               DTINIPERPREV, DTFINPERPREV)
            VALUES(
               P_CDFILIAL,    P_NRPREVISAO, LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
               V_NRPAGINA,    '04',         C_EMP.CDEMPRESA,
               '0000000000',  'E',
               C_DATA.DTDATA, V_TOTALDIA,
               P_DTPERIINIC,  P_DTPERIFINA);
         END IF;

         /* CONTROLA A COLUNA E A PGINA DO RELATRIO */
         V_NRCOLUNA   := V_NRCOLUNA + 1;
         IF V_NRCOLUNA > 6 THEN
            V_NRPAGINA   := V_NRPAGINA + 1;
            V_NRCOLUNA   := 1;
            V_NRREGIENCA := V_NRREGIENCA + 1;
         END IF;
      END LOOP;
      V_NRREGIENCA := V_NRREGIENCA + 1;
   END LOOP;

   FOR C_EMP IN C_EMPRESA LOOP
      V_NRPAGINA   := 1;
      V_NRCOLUNA   := 1;

      SELECT COUNT(*) INTO V_CTCONTA
      FROM
         NOTAFISCAL NF,
         CONTAPAGAR CP
      WHERE
         CP.CDEMPRESA    = C_EMP.CDEMPRESA          AND
         CP.DTATUAVENPAG BETWEEN (P_DTPERIINIC - 1) AND P_DTPERIFINA AND
         NF.CDFILIAL     = CP.CDFILIAL              AND
         NF.NRLANCTONF   = CP.NRLANCTONF            AND
         NF.IDSTATUS     = 'V';

      IF V_CTCONTA > 0 THEN
         FOR C_DATA IN C_PERIODO LOOP

            SELECT SUM(VRATUAPAG)
            INTO V_TOTALDIA
            FROM
               NOTAFISCAL NF,
               CONTAPAGAR CP
            WHERE
               CP.CDEMPRESA    = C_EMP.CDEMPRESA     AND
               CP.DTATUAVENPAG = C_DATA.DTDATA       AND
               NF.CDFILIAL     = CP.CDFILIAL         AND
               NF.NRLANCTONF   = CP.NRLANCTONF       AND
               NF.IDSTATUS     = 'V';

            IF V_TOTALDIA > 0 THEN
               V_TOTALDIA := V_TOTALDIA * -1;
            END IF;

            IF (V_NRCOLUNA > 1) THEN
               ALTERA_TRAB_PREV(P_CDFILIAL, P_NRPREVISAO,  LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
                                V_NRCOLUNA, C_DATA.DTDATA, V_TOTALDIA);
            ELSE
               INSERT INTO TRAB_PREV(
                  CDFILIPREV,   NRPREVISAO, NRREGIPREV,
                  NRPAGIPREV,   CDGRUPPREV, CDEMPRPREV,
                  CDITEMPREV,   DSITEMPREV,
                  DTDIA01PREV,  VRDIA01PREV,
                  DTINIPERPREV, DTFINPERPREV)
               VALUES(
                  P_CDFILIAL    , P_NRPREVISAO, LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
                  V_NRPAGINA    , '05'        , C_EMP.CDEMPRESA,
                  ''            , ''          ,
                  C_DATA.DTDATA , V_TOTALDIA  ,
                  P_DTPERIINIC  , P_DTPERIFINA);
            END IF;

            /* CONTROLA A COLUNA E A PGINA DO RELATRIO */
            V_NRCOLUNA   := V_NRCOLUNA + 1;
            IF V_NRCOLUNA > 6 THEN
               V_NRPAGINA   := V_NRPAGINA + 1;
               V_NRCOLUNA   := 1;
               V_NRREGIENCA := V_NRREGIENCA + 1;
            END IF;
         END LOOP;
         V_NRREGIENCA := V_NRREGIENCA + 1;
      END IF;
   END LOOP;

   V_TOTMOVIANT := 0;
   FOR C_MOVI IN
   (SELECT NRPAGIPREV,
      MAX(DTDIA01PREV) DT01, MAX(DTDIA02PREV) DT02, MAX(DTDIA03PREV) DT03,
      MAX(DTDIA04PREV) DT04, MAX(DTDIA05PREV) DT05, MAX(DTDIA06PREV) DT06,
      SUM(VRDIA01PREV) DIA01, SUM(VRDIA02PREV) DIA02, SUM(VRDIA03PREV) DIA03,
      SUM(VRDIA04PREV) DIA04, SUM(VRDIA05PREV) DIA05, SUM(VRDIA06PREV) DIA06
    FROM TRAB_PREV
    WHERE
      CDFILIPREV = P_CDFILIAL AND
      NRPREVISAO = P_NRPREVISAO AND
      CDGRUPPREV <> '01'
    GROUP BY NRPAGIPREV) LOOP
/*      DBMS_OUTPUT.PUT_LINE('AREC: '||LPAD(TO_CHAR(V_NRREGIENCA), 10, '0')||'-'||C_MOVI.NRPAGIPREV||'-'||V_TOTMOVIANT||'-'||V_VRDIA01);*/
      V_NRREGIENCA := V_NRREGIENCA + 1;
      INSERT INTO TRAB_PREV(
         CDFILIPREV,   NRPREVISAO, NRREGIPREV,
         NRPAGIPREV,   CDGRUPPREV, CDEMPRPREV,
         CDITEMPREV,   DSITEMPREV,
         DTDIA01PREV,  VRDIA01PREV,
         DTDIA02PREV,  VRDIA02PREV,
         DTDIA03PREV,  VRDIA03PREV,
         DTDIA04PREV,  VRDIA04PREV,
         DTDIA05PREV,  VRDIA05PREV,
         DTDIA06PREV,  VRDIA06PREV,
         DTINIPERPREV, DTFINPERPREV)
      VALUES(
         P_CDFILIAL,    P_NRPREVISAO, LPAD(TO_CHAR(V_NRREGIENCA), 10, '0'),
         C_MOVI.NRPAGIPREV,    '99',         '',
         '',         '',
         C_MOVI.DT01, V_TOTMOVIANT,
         C_MOVI.DT02, V_TOTMOVIANT + C_MOVI.DIA01,
         C_MOVI.DT03, V_TOTMOVIANT + C_MOVI.DIA01 + C_MOVI.DIA02,
         C_MOVI.DT04, V_TOTMOVIANT + C_MOVI.DIA01 + C_MOVI.DIA02 + C_MOVI.DIA03,
         C_MOVI.DT05, V_TOTMOVIANT + C_MOVI.DIA01 + C_MOVI.DIA02 + C_MOVI.DIA03 + C_MOVI.DIA04,
         C_MOVI.DT06, V_TOTMOVIANT + C_MOVI.DIA01 + C_MOVI.DIA02 + C_MOVI.DIA03 + C_MOVI.DIA04 + C_MOVI.DIA05,
         P_DTPERIINIC,  P_DTPERIFINA);

      V_TOTMOVIANT := V_TOTMOVIANT +
                      NVL(C_MOVI.DIA01, 0) + NVL(C_MOVI.DIA02, 0) + NVL(C_MOVI.DIA03, 0) +
                      NVL(C_MOVI.DIA04, 0) + NVL(C_MOVI.DIA05, 0) + NVL(C_MOVI.DIA06, 0);
   END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('GERA_TRAB_PREV_RISOTOLANDIA','6.35.031'); END;
/

